@@ -1,5 +1,5 @@
 `rankabuncomp` <-
-function(x, y=NULL, factor=NULL,
+function(x, y=NULL, factor=NULL, return.data=T, specnames=c(1:3),
     scale="abundance", scaledx=F, type="o", rainbow=T, legend=T, 
     xlim=c(1, max1), ylim=c(0, max2), 
     ...
@@ -20,7 +20,6 @@ function(x, y=NULL, factor=NULL,
     }
     if (scale=="accumfreq") {max2 <- 100}
     max2 <- as.numeric(max2)
-
     if (rainbow==F) {
         if (scale == "logabun" && all.equal(ylim, c(0, max2)) == T) {ylim <- c(1, max2)}
         rankabunplot(rankabundance(x, y, factor, levels[1]), scale=scale, scaledx=scaledx, type=type, labels=levels[1], xlim=xlim, ylim=ylim, pch=1, specnames=NULL, ...)
@@ -38,5 +37,20 @@ function(x, y=NULL, factor=NULL,
         if (legend==T) {legend(graphics::locator(1), legend=levels, pch=c(1:m), col=c(1:m))}
         grDevices::palette("default")
     }
+    
+    if (return.data == T) {
+        for (i in 1:m) {
+            resulti <- data.frame(rankabundance(x, y, factor, levels[i]))
+            resulti <- data.frame(Grouping=rep(levels[i], nrow(resulti)), species=rownames(resulti), labelit=rep(FALSE, nrow(resulti)), resulti)            
+            spec.max <- min(max(specnames), nrow(resulti))
+            resulti[c(1:spec.max), "labelit"] <- as.logical(1)
+            rownames(resulti) <- NULL
+            if (i == 1) {
+                result <- resulti
+            }else{
+                result <- rbind(result, resulti)
+            }
+        }
+        return(result)
+    }   
 }
-
